@@ -22,7 +22,8 @@
 #define ALL_H
 
 typedef float		real;		// float should be enough
-typedef short		bool;
+//typedef short		bool;
+typedef short BOOL;
 typedef unsigned	uint32;		// 32 Bit unsigned integer
 	// some compilers may need "typedef unsigned long uint32" instead
 typedef int		int32;		// 32 Bit signed integer
@@ -32,13 +33,22 @@ typedef short		int16;		// 16 Bit signed integer
 
 typedef unsigned char	ulawsample;	// u-law byte
 
+typedef uint32 DWORD;
+
 #ifndef True
 #define True	1
 #define False	0
 #endif
 
+#ifndef TRUE
+#define TRUE	1
+#define FALSE	0
+#endif
+
 #ifdef SunOS4_1_1
 #define ULAW 1
 #endif
 
+enum e_channels { both, left, right, downmix };
+
 #endif
