@@ -1,5 +1,5 @@
 /*
- *  @(#) subband.h 1.7, last edit: 25 Oct 1994 16:07:45
+ *  @(#) subband.h 1.6, last edit: 6/15/94 16:55:36
  *  @(#) Copyright (C) 1993, 1994 Tobias Bading (bading@cs.tu-berlin.de)
  *  @(#) Berlin University of Technology
  *
@@ -27,16 +27,14 @@
 #include "synthesis_filter.h"
 #include "crc.h"
 
-enum e_channels { both, left, right };
-
 // abstract base class for subband classes of layer I and II:
 class Subband
 {
 public:
   virtual void read_allocation (Ibitstream *, Header *, Crc16 *) = 0;
   virtual void read_scalefactor (Ibitstream *, Header *) = 0;
-  virtual boil read_sampledata (Ibitstream *) = 0;
-  virtual boil put_next_sample (e_channels, SynthesisFilter *, SynthesisFilter *) = 0;
+  virtual bool read_sampledata (Ibitstream *) = 0;
+  virtual bool put_next_sample (e_channels, SynthesisFilter *, SynthesisFilter *) = 0;
 };
 
 #endif
